@@ -2,14 +2,14 @@
 Date         : 2022-10-25 15:44:41
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2023-10-11 13:52:14
+LastEditTime : 2023-10-11 14:22:31
 LastEditors  : BDFD
 Description  : 
 FilePath     : \execdata\__init__.py
 Copyright (c) 2022 by BDFD, All Rights Reserved. 
 '''
 
-from execdata.templateproj import add_one
+from execdata.templateproj import add_one, add_two
 from execdata.data_conversion import convint, convfloat
 from execdata.data_preprocess import filtered_value_list
 from execdata.standardization import encode, sep, split, strat_split
